=======
History
=======

0.0.0 (2018-09-28)
------------------

* Initial alpha release

2.1.0
------------------

* Revamped official release

2.1.1
------------------

* File upload bug fixes

2.2.1
------------------

* Better Documentation

2.2.2
------------------

* Fix pypi readme formatting

2.3.0
------------------

* Add get_list_of_jobs

2.4.0
------------------

* Add support for custom vocabularies

2.5.0
------------------

* Add examples
* Improve error handling
* Add streaming client

2.6.0
------------------

* Support skip_punctuation
* Support .vtt captions output
* Support speaker channel jobs

2.6.1
------------------

* Add metadata to streaming client

2.7.0
------------------

* Add custom vocabularies to streaming client

2.7.1
------------------

* Use v1 of the streaming api
* Add custom vocabulary to async example
* Add filter_profanity to async and streaming clients, examples, and documentation
* Add remove_disfluencies to async client